@@ -62,10 +62,10 @@ class DynamoDBStreamsToLambda(
         :param id: - this is a a scope-unique id.
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param dynamo_table_props: Optional user provided props to override the default props for the DynamoDB Table. Providing both this and ``existingTableInterface`` is an error. Default: - Partition key ID: string
+        :param dynamo_table_props: Optional user provided props to override the default props for the DynamoDB Table. Providing both this and ``existingTableInterface`` causes an error. Default: - Partition key ID: string
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_table_interface: Optional - existing DynamoDB table, providing both this and ``dynamoTableProps`` will cause an error. Default: - None
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default props are used
         :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
 
         :access: public
@@ -131,10 +131,10 @@ class DynamoDBStreamsToLambdaProps:
         '''
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
-        :param dynamo_table_props: Optional user provided props to override the default props for the DynamoDB Table. Providing both this and ``existingTableInterface`` is an error. Default: - Partition key ID: string
+        :param dynamo_table_props: Optional user provided props to override the default props for the DynamoDB Table. Providing both this and ``existingTableInterface`` causes an error. Default: - Partition key ID: string
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_table_interface: Optional - existing DynamoDB table, providing both this and ``dynamoTableProps`` will cause an error. Default: - None
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default props are used
         :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
 
         :summary: The properties for the DynamoDBStreamsToLambda Construct
@@ -195,7 +195,7 @@ class DynamoDBStreamsToLambdaProps:
         '''Optional user provided props to override the default props for the DynamoDB Table.
 
         Providing both this and
-        ``existingTableInterface`` is an error.
+        ``existingTableInterface`` causes an error.
 
         :default: - Partition key ID: string
         '''
@@ -230,7 +230,8 @@ class DynamoDBStreamsToLambdaProps:
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional - user provided props to override the default props for the Lambda function.
 
-        Providing both this and ``existingLambdaObj`` is an error.
+        Providing both this and ``existingLambdaObj``
+        causes an error.
 
         :default: - Default props are used
         '''
